@@ -7,4 +7,6 @@ from .calculations import sort_nearest_points_from_on_plane_y as SortPointsFromP
 from .calculations import calculate_reflection_angle as RefAngle
 from .converters import outdoor_traced_result_to_line as OutdoorResultToLines
 from .converters import dbm_to_mw as dBmTomW
-from .converters import mw_to_dbm as mWTodBm
\ No newline at end of file
+from .converters import mw_to_dbm as mWTodBm
+from .notebook import is_notebook as IsNotebook
+from .plotter import Plotter
\ No newline at end of file
